import { ExtractPropTypes, PropType } from 'vue';
import { IDay } from './types';
export type CalendarValue = string | Array<string>;
/**
 * 日历选择类型
 * single：单选
 * multiple：多选
 * range：日期区间
 */
export type CalendarType = 'single' | 'multiple' | 'range';
/**
 * 单个日期格式化
 */
export type CalendarDayFormatter = (day: IDay) => IDay;
export type CalendarProps = ExtractPropTypes<typeof CALENDAR_PROPS>;
export declare const CALENDAR_PROPS: {
    modelValue: {
        type: PropType<CalendarValue>;
        default: undefined;
    };
    type: {
        type: PropType<CalendarType>;
        default: CalendarType;
    };
    /**
     * 可选最小日期，默认当前日期
     */
    minDate: {
        type: DateConstructor;
        default: Date;
    };
    /**
     * 可选最大日期，默认当前日期的后 1 年
     */
    maxDate: {
        type: DateConstructor;
        default: Date;
    };
    placeholder: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 弹出框标题
     */
    title: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 显示日期格式化
     */
    displayFormatter: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 已选数据格式化
     */
    valueFormatter: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 月份格式化
     */
    monthFormatter: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 单个日期格式化
     */
    formatter: {
        type: PropType<CalendarDayFormatter>;
        default: undefined;
    };
    /**
     * 确认按钮文字
     */
    confirmButtonText: {
        type: StringConstructor;
        default: string;
    };
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    readonly: {
        type: BooleanConstructor;
        default: boolean;
    };
};
