import { ExtractPropTypes, PropType } from 'vue';
import { DateTimePickerOption } from './types';
export type DateTimePickerType = 'date' | 'year-month' | 'month-day' | 'time' | 'datetime' | 'date-hour';
export type DateTimePickerValue = string | number | Date;
export type DateTimePickerFormatter<V extends string | number = string> = (type: DateTimePickerOption['type'], value: V) => V;
export type DateTimePickerProps = ExtractPropTypes<typeof DATE_PICKER_PROPS>;
export declare const DATE_PICKER_PROPS: {
    modelValue: {
        type: PropType<DateTimePickerValue>;
        default: undefined;
    };
    /**
     * 显示隐藏
     */
    visible: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 提示语
     */
    placeholder: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 支持设置一个顶部标题
     */
    title: StringConstructor;
    /**
     * 日期格式
     */
    type: {
        type: PropType<DateTimePickerType>;
        default: string;
    };
    /**
     * 显示内容格式化
     */
    displayFormatter: StringConstructor;
    /**
     * 可选最小日期，默认当前日期的前 10 年
     */
    minDate: {
        type: DateConstructor;
        default: Date;
    };
    /**
     * 可选最大日期，默认当前日期的后 10 年
     */
    maxDate: {
        type: DateConstructor;
        default: Date;
    };
    /**
     * 每列格式化函数
     */
    formatter: {
        type: PropType<DateTimePickerFormatter<string>>;
        default: undefined;
    };
    className: {
        type: PropType<import("@xuanmo/dl-common").ClassName>;
        default: undefined;
    };
    rowId: {
        type: StringConstructor;
        default: undefined;
    };
    model: {
        type: PropType<import("@xuanmo/dl-common").IFormModelItem<unknown>>;
        default: undefined;
    };
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    readonly: {
        type: BooleanConstructor;
        default: boolean;
    };
    keys: {
        type: PropType<import("@xuanmo/dl-common").CustomKeys>;
        default: undefined;
    };
    lockScroll: {
        type: BooleanConstructor;
        default: boolean;
    };
    teleport: {
        type: PropType<string | import("vue").RendererElement | null | undefined>;
        default: string;
    };
    lazyRender: {
        type: BooleanConstructor;
        default: boolean;
    };
    requiredMarkPosition: PropType<"left" | "right">;
    labelWidth: PropType<string | number>;
    clientType: PropType<"PC" | "MOBILE">;
    border: {
        type: BooleanConstructor;
        default: undefined;
    };
    round: {
        type: BooleanConstructor;
        default: undefined;
    };
    separator: {
        type: StringConstructor;
        default: undefined;
    };
    closeOnEsc: {
        type: BooleanConstructor;
        default: undefined;
    };
    direction: {
        type: PropType<import("@xuanmo/dl-common").DirectionType>;
        default: undefined;
    };
    idGenerator: {
        type: PropType<() => string>;
        default: undefined;
    };
};
